Quantum Electrostatic Heterostructure Model
===========================================
The quantum electrostatic heterostructure (QEH) model is a
fast and accurate model for simulating optical properties
of stacks of 2D materials (heterostructures).

- Documentation: https://qeh.readthedocs.io
- Code: https://gitlab.com/camd/qeh.git
